@@ -307,8 +307,7 @@ def _periods_for_range(start_date, end_date):
 def _period_for_week(year, week_number):
     """returns a pandas.Period for a given growing season year and week number"""
     first_sunday = _first_sunday(year)
-    period = pandas.Period(first_sunday, freq='W-SAT') + week_number - 1
-    return period
+    return pandas.Period(first_sunday, freq='W-SAT') + week_number - 1
 
 
 def _reindex_data(dataframe):
@@ -331,7 +330,9 @@ def _value_dict(value):
 def _week_number(date):
     """returns the growing season week number for a given datetime.date"""
     first_sunday = _first_sunday(date.year)
-    if date < first_sunday:
-        first_sunday = _first_sunday(date.year - 1)
-    days_since_first_sunday = (date - first_sunday).days
+    date_ts = pandas.Timestamp(date)
+    first_sunday_ts = pandas.Timestamp(first_sunday)
+    if date_ts < first_sunday_ts:
+        first_sunday_ts = pandas.Timestamp(_first_sunday(date.year - 1))
+    days_since_first_sunday = (date_ts - first_sunday_ts).days
     return (first_sunday.year, (days_since_first_sunday / 7) + 1)
